@@ -449,7 +449,7 @@ class frmRecordWindow(QtGui.QWidget):
 
     def closeEvent(self, event):
         #check if user wants to keep this record
-        reply = QtGui.QMessageBox.question(self, 'Keep Logfile?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, 'Keep this Record?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.No:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
