@@ -148,12 +148,12 @@ def showGraph(self,  QtGui):
 
         x=data.arrDataIndex/Xscale
         if(x>775): 
-            shift=(x-775)*Xscale
-#            print "Curve too long,  dropping first",  shift,  "values"
-        else: shift=0
+            GraphStart=(x-775)*Xscale
+            print "Graph too long, only show values",  GraphStart,  "to",  x
+        else: GraphStart=0
             
         try:
-            t=string.split(data.arrData[0][shift], ":")
+            t=string.split(data.arrData[0][GraphStart], ":")
             h0=int(t[0])
             m0=int(t[1])
         except:
@@ -175,7 +175,6 @@ def showGraph(self,  QtGui):
         offset=minutestonexthour*decade/60
         
         
-        Show_passed_time("2")
         
         #main lines + text
         if(data.test==0):
@@ -193,18 +192,21 @@ def showGraph(self,  QtGui):
         #trigger line
         y=(data.Ysize-(data.trigger*data.Yscale))-2
         paint.drawLine(1, y-15, 781, y-15)  
+        paint.drawText(760, y-17, str(data.trigger))
+        
+        #show y scale
+        paint.drawText(5, 15, str(data.Yscale))
 
 
-        Show_passed_time("4")
 
         #draw graph
         lastmove=0
-#        print shift,  data.arrDataIndex-data.derivation,  Xscale
+#        print GraphStart,  data.arrDataIndex-data.derivation,  Xscale
         
-        end=data.arrDataIndex-shift-data.derivation
+        end=data.arrDataIndex-GraphStart-data.derivation
         peak=0   
         for i in range(0,  end,  Xscale):
-            k=i+shift
+            k=i+GraphStart
             
             
             
